<?php
namespace XLite\Module\XC\FastLaneCheckout\View\Sections;
/**
 * Widget class of Payment section of the fastlane checkout
 */
class Payment extends \XLite\Module\XC\MailChimp\View\FastLane {}